# Quickstart

## Installation

```
$ pip install assemblyinfo
```

To install the latest development version of bioframe from github, first make a local clone of the github repository:

```
$ git clone https://github.com/open2c/assemblyinfo
```

Then, compile and install bioframe in [development mode](https://setuptools.readthedocs.io/en/latest/setuptools.html#development-mode). This installs the package without moving it to a system folder, and thus allows for testing changes to the python code on the fly.

```
$ cd assemblyinfo
$ pip install -e ./
```
